/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataLaunchdarklyFlagTriggerConfig extends cdktf.TerraformMetaArguments {
    /**
    * The unique key of the environment the flag trigger will work in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.20.0/docs/data-sources/flag_trigger#env_key DataLaunchdarklyFlagTrigger#env_key}
    */
    readonly envKey: string;
    /**
    * The unique key of the associated flag.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.20.0/docs/data-sources/flag_trigger#flag_key DataLaunchdarklyFlagTrigger#flag_key}
    */
    readonly flagKey: string;
    /**
    * The Terraform trigger ID. The unique trigger ID can be found in your saved trigger URL:
    *
    * ```
    * https://app.launchdarkly.com/webhook/triggers/THIS_IS_YOUR_TRIGGER_ID/aff25a53-17d9-4112-a9b8-12718d1a2e79
    * ```
    *
    * Please note that if you did not save this upon creation of the resource, you will have to reset it to get a new value, which can cause breaking changes.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.20.0/docs/data-sources/flag_trigger#id DataLaunchdarklyFlagTrigger#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * The unique key of the project encompassing the associated flag.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.20.0/docs/data-sources/flag_trigger#project_key DataLaunchdarklyFlagTrigger#project_key}
    */
    readonly projectKey: string;
}
export interface DataLaunchdarklyFlagTriggerInstructions {
}
export declare function dataLaunchdarklyFlagTriggerInstructionsToTerraform(struct?: DataLaunchdarklyFlagTriggerInstructions): any;
export declare function dataLaunchdarklyFlagTriggerInstructionsToHclTerraform(struct?: DataLaunchdarklyFlagTriggerInstructions): any;
export declare class DataLaunchdarklyFlagTriggerInstructionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataLaunchdarklyFlagTriggerInstructions | undefined;
    set internalValue(value: DataLaunchdarklyFlagTriggerInstructions | undefined);
    get kind(): string;
}
export declare class DataLaunchdarklyFlagTriggerInstructionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataLaunchdarklyFlagTriggerInstructionsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.20.0/docs/data-sources/flag_trigger launchdarkly_flag_trigger}
*/
export declare class DataLaunchdarklyFlagTrigger extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "launchdarkly_flag_trigger";
    /**
    * Generates CDKTF code for importing a DataLaunchdarklyFlagTrigger resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataLaunchdarklyFlagTrigger to import
    * @param importFromId The id of the existing DataLaunchdarklyFlagTrigger that should be imported. Refer to the {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.20.0/docs/data-sources/flag_trigger#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataLaunchdarklyFlagTrigger to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.20.0/docs/data-sources/flag_trigger launchdarkly_flag_trigger} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataLaunchdarklyFlagTriggerConfig
    */
    constructor(scope: Construct, id: string, config: DataLaunchdarklyFlagTriggerConfig);
    get enabled(): cdktf.IResolvable;
    private _envKey?;
    get envKey(): string;
    set envKey(value: string);
    get envKeyInput(): string | undefined;
    private _flagKey?;
    get flagKey(): string;
    set flagKey(value: string);
    get flagKeyInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _instructions;
    get instructions(): DataLaunchdarklyFlagTriggerInstructionsList;
    get integrationKey(): string;
    get maintainerId(): string;
    private _projectKey?;
    get projectKey(): string;
    set projectKey(value: string);
    get projectKeyInput(): string | undefined;
    get triggerUrl(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
